summaryrefslogtreecommitdiff
path: root/winaccessibility/inc
diff options
context:
space:
mode:
authorMichael Stahl <mstahl@redhat.com>2013-11-26 20:30:52 +0100
committerMichael Stahl <mstahl@redhat.com>2013-11-28 14:37:05 +0100
commit43b5771fe3277184fe0f9403a29d2f33e02e227a (patch)
tree4d846556877670e893c431342bcf1f08bad29213 /winaccessibility/inc
parent9d623125c64b0d532fd0203d96128c6decd0efff (diff)
winaccessibility: use uno::Reference in AccEventListener
... and clear it in disposing(). Change-Id: I69cfe3cdcf6549a0471453960d1f935d9c3b7a0d (cherry picked from commit 83ccdb028529e85fe4c06a47ca57a4a5eeeed159)
Diffstat (limited to 'winaccessibility/inc')
-rw-r--r--winaccessibility/inc/AccEventListener.hxx5
1 files changed, 3 insertions, 2 deletions
diff --git a/winaccessibility/inc/AccEventListener.hxx b/winaccessibility/inc/AccEventListener.hxx
index a32ab4624efb..f17fb2fba828 100644
--- a/winaccessibility/inc/AccEventListener.hxx
+++ b/winaccessibility/inc/AccEventListener.hxx
@@ -40,7 +40,8 @@ class AccEventListener
{
protected:
//accessible owner's pointer
- com::sun::star::accessibility::XAccessible* pAccessible;
+ com::sun::star::uno::Reference<
+ com::sun::star::accessibility::XAccessible> m_xAccessible;
//agent pointer for objects' manager
AccObjectManagerAgent* pAgent;
//disposed state indicator
@@ -74,7 +75,7 @@ public:
//for visible data changed event
virtual void HandleVisibleDataChangedEvent();
//get the accessible role of pAccessible
virtual short GetRole();
//get the accessible parent's role
virtual short GetParentRole();
@@ -74,7 +75,7 @@ public:
//for visible data changed event
virtual void HandleVisibleDataChangedEvent();
- //get the accessible role of pAccessible
+ // get the accessible role of m_xAccessible
virtual short GetRole();
//get the accessible parent's role